##  When to Use Tags
Do use tags when:
  * You need quick, high-level classification. Use them for the most important and most prominent attributes (for example, a strategic initiative, an SLA classification, or any other clustering across fact sheet types).
  * The value set is small (fewer than 10 options). Using no more than 5-7 tag groups per fact sheet type is good practice.
  * You want to depict a relatively temporary status since it is easy and convenient to add/remove tags and entire tag groups.


Don’t use tags when:
  * Something can be modeled adequately using the SAP LeanIX meta model.
  * You already have more than seven tag groups applicable for the same fact sheet type. Consider moving a tag group to a field before introducing a new one.
  * It adds another data point relevant to a use case and stakeholders.
